@@ -43,7 +43,7 @@ ec_draw (ECellView *ecell_view, GdkDrawable *drawable,
 }
 
 static gint
-ec_event (ECellView *ecell_view, GdkEvent *event, int model_col, int view_col, int row, ECellFlags flags)
+ec_event (ECellView *ecell_view, GdkEvent *event, int model_col, int view_col, int row, ECellFlags flags, ECellActions *actions)
 {
 	g_error ("e-cell-event invoked\n");
 	return 0;
@@ -52,7 +52,7 @@ ec_event (ECellView *ecell_view, GdkEvent *event, int model_col, int view_col, i
 static gint
 ec_height (ECellView *ecell_view, int model_col, int view_col, int row)
 {
-	g_error ("e-cell-event invoked\n");
+	g_error ("e-cell-height invoked\n");
 	return 0;
 }
 
@@ -90,7 +90,7 @@ ec_leave_edit (ECellView *ecell_view, int model_col, int view_col, int row, void
 }
 
 static void
-ec_show_tooltip (ECellView *ecell_view, int model_col, int view_col, int row, ETableTooltip *tooltip)
+ec_show_tooltip (ECellView *ecell_view, int model_col, int view_col, int row, int col_width, ETableTooltip *tooltip)
 {
 	/* Do nothing */
 }
@@ -131,16 +131,18 @@ E_MAKE_TYPE(e_cell, "ECell", ECell, e_cell_class_init, e_cell_init, PARENT_TYPE)
  * @model_col: the column in the model
  * @view_col: the column in the view
  * @row: the row
+ * @flags: flags about the current state
+ * @actions: A second return value in case the cell wants to take some action (specifically grabbing & ungrabbing)
  *
  * Dispatches the event @event to the @ecell_view for.
  *
  * Returns: processing state from the GdkEvent handling.
  */
 gint
-e_cell_event (ECellView *ecell_view, GdkEvent *event, int model_col, int view_col, int row, ECellFlags flags)
+e_cell_event (ECellView *ecell_view, GdkEvent *event, int model_col, int view_col, int row, ECellFlags flags, ECellActions *actions)
 {
 	return E_CELL_CLASS (GTK_OBJECT (ecell_view->ecell)->klass)->event (
-		ecell_view, event, model_col, view_col, row, flags);
+		ecell_view, event, model_col, view_col, row, flags, actions);
 }
 
 /** 
@@ -226,7 +228,8 @@ e_cell_unrealize (ECellView *ecell_view)
  */
 void
 e_cell_draw (ECellView *ecell_view, GdkDrawable *drawable,
-	     int model_col, int view_col, int row, ECellFlags flags, int x1, int y1, int x2, int y2)
+	     int model_col, int view_col, int row, ECellFlags flags,
+	     int x1, int y1, int x2, int y2)
 {
 	E_CELL_CLASS (GTK_OBJECT (ecell_view->ecell)->klass)->draw (
 		ecell_view, drawable, model_col, view_col, row, flags, x1, y1, x2, y2);
@@ -234,6 +237,13 @@ e_cell_draw (ECellView *ecell_view, GdkDrawable *drawable,
 
 /**
  * e_cell_print:
+ * @ecell_view: the ECellView to redraw
+ * @context: The GnomePrintContext where we output our printed data.
+ * @model_col: the column in the model being drawn.
+ * @view_col: the column in the view being drawn (what the model maps to).
+ * @row: the row being drawn
+ * @width: width 
+ * @height: height
  *
  * FIXME:
  */
@@ -303,6 +313,7 @@ e_cell_enter_edit (ECellView *ecell_view, int model_col, int view_col, int row)
  * @model_col: the column in the model
  * @view_col: the column in the view
  * @row: the row
+ * @edit_context: the editing context
  *
  * Notifies the ECellView that editing is finished at @model_col, @row
  * rendered at @view_col, @row.
@@ -332,8 +343,8 @@ e_cell_max_width (ECellView *ecell_view, int model_col, int view_col)
 	      
 void
 e_cell_show_tooltip (ECellView *ecell_view, int model_col, int view_col, 
-		     int row, ETableTooltip *tooltip)
+		     int row, int col_width, ETableTooltip *tooltip)
 {
 	return E_CELL_CLASS (GTK_OBJECT (ecell_view->ecell)->klass)->show_tooltip
-		(ecell_view, model_col, view_col, row, tooltip);
+		(ecell_view, model_col, view_col, row, col_width, tooltip);
 }
