@@ -327,10 +327,10 @@ child_cursor_change (ETableGroup *etg, int row,
 }
 
 static void
-child_double_click (ETableGroup *etg, int row,
+child_double_click (ETableGroup *etg, int row, int col, GdkEvent *event,
 		    ETableGroupContainer *etgc)
 {
-	e_table_group_double_click (E_TABLE_GROUP (etgc), row);
+	e_table_group_double_click (E_TABLE_GROUP (etgc), row, col, event);
 }
 
 static gint
@@ -499,38 +499,6 @@ etgc_decrement (ETableGroup *etg, gint position, gint amount)
 					 position, amount);
 }
 
-static void
-etgc_set_cursor_row (ETableGroup *etg, gint row)
-{
-	ETableGroupContainer *etgc = E_TABLE_GROUP_CONTAINER(etg);
-	GList *list;
-	for (list = etgc->children; list; list = g_list_next(list)) {
-		ETableGroup *group = ((ETableGroupContainerChildNode *)list->data)->child;
-		gint this_count = e_table_group_row_count(group);
-		if (row < this_count) {
-			e_table_group_set_cursor_row(group, row);
-			return;
-		}
-		row -= this_count;
-	}
-}
-
-static int
-etgc_get_cursor_row (ETableGroup *etg)
-{
-	ETableGroupContainer *etgc = E_TABLE_GROUP_CONTAINER(etg);
-	GList *list;
-	int count = 0;
-	for (list = etgc->children; list; list = g_list_next(list)) {
-		ETableGroup *group = ((ETableGroupContainerChildNode *)list->data)->child;
-		int row = e_table_group_get_cursor_row(group);
-		if (row != -1)
-			return count + row;
-		count += e_table_group_row_count(group);
-	}
-	return -1;
-}
-
 static void
 etgc_set_focus (ETableGroup *etg, EFocus direction, gint view_col)
 {
@@ -726,8 +694,6 @@ etgc_class_init (GtkObjectClass *object_class)
 	e_group_class->decrement  = etgc_decrement;
 	e_group_class->row_count  = etgc_row_count;
 	e_group_class->set_focus  = etgc_set_focus;
-	e_group_class->set_cursor_row = etgc_set_cursor_row;
-	e_group_class->get_cursor_row = etgc_get_cursor_row;
 	e_group_class->get_focus_column = etgc_get_focus_column;
 	e_group_class->get_printable = etgc_get_printable;
 	e_group_class->compute_location = etgc_compute_location;
