@@ -85,14 +85,23 @@ ethi_destroy (GtkObject *object){
 
 	ethi_drop_table_header (ethi);
 
-	if (ethi->sort_info){
+	if (ethi->dnd_code) {
+		g_free (ethi->dnd_code);
+		ethi->dnd_code = NULL;
+	}
+
+	if (ethi->sort_info) {
 		if (ethi->sort_info_changed_id)
 			gtk_signal_disconnect (GTK_OBJECT(ethi->sort_info), ethi->sort_info_changed_id);
 		if (ethi->group_info_changed_id)
 			gtk_signal_disconnect (GTK_OBJECT(ethi->sort_info), ethi->group_info_changed_id);
 		gtk_object_unref (GTK_OBJECT(ethi->sort_info));
+		ethi->sort_info = NULL;
 	}
 
+	if (ethi->full_header)
+		gtk_object_unref (GTK_OBJECT(ethi->full_header));
+
 	if (GTK_OBJECT_CLASS (ethi_parent_class)->destroy)
 		(*GTK_OBJECT_CLASS (ethi_parent_class)->destroy) (object);
 }
@@ -904,7 +913,8 @@ set_cursor (ETableHeaderItem *ethi, int pos)
 	if (resizeable)
 		e_cursor_set (canvas->window, E_CURSOR_SIZE_X);
 	else
-		e_cursor_set (canvas->window, E_CURSOR_ARROW);
+		gdk_window_set_cursor (canvas->window, NULL);
+	/*		e_cursor_set (canvas->window, E_CURSOR_ARROW);*/
 }
 
 static void
@@ -1256,7 +1266,8 @@ ethi_event (GnomeCanvasItem *item, GdkEvent *e)
 		break;
 
 	case GDK_LEAVE_NOTIFY:
-		e_cursor_set (GTK_WIDGET (canvas)->window, E_CURSOR_ARROW);
+		gdk_window_set_cursor (GTK_WIDGET (canvas)->window, NULL);
+		/*		e_cursor_set (GTK_WIDGET (canvas)->window, E_CURSOR_ARROW);*/
 		break;
 			    
 	case GDK_MOTION_NOTIFY:
