@@ -290,7 +290,7 @@ e_table_subset_new (ETableModel *source, const int nvals)
 	ETableSubset *etss = gtk_type_new (E_TABLE_SUBSET_TYPE);
 
 	if (e_table_subset_construct (etss, source, nvals) == NULL){
-		gtk_object_destroy (GTK_OBJECT (etss));
+		gtk_object_unref (GTK_OBJECT (etss));
 		return NULL;
 	}
 
