@@ -584,7 +584,7 @@ static ColorNamePair default_color_set [] = {
  *
  */
 GtkWidget*
-color_palette_new (char const * const no_color_label,
+color_palette_new (const char *no_color_label,
 		   GdkColor *default_color, const gchar *group_name)
 {
 	/* specify 6 rows to allow for a row of custom colors */
