@@ -3,6 +3,10 @@
 
 #include <gal/widgets/gtk-combo-box.h>
 
+#ifdef __cplusplus
+extern "C" {
+#endif /* __cplusplus */
+
 #define GTK_COMBO_TEXT(obj)	    GTK_CHECK_CAST (obj, gtk_combo_text_get_type (), GtkComboText)
 #define GTK_COMBO_TEXT_CLASS(klass) GTK_CHECK_CLASS_CAST (klass, gtk_combo_text_get_type (), GtkComboTextClass)
 #define GTK_IS_COMBO_TEXT(obj)      GTK_CHECK_TYPE (obj, gtk_combo_text_get_type ())
@@ -41,4 +45,8 @@ void       gtk_combo_text_add_item    (GtkComboText *combo_text,
 				       const gchar *item,
 				       const gchar *value);
 
+#ifdef __cplusplus
+};
+#endif /* __cplusplus */
+
 #endif
